# coding: utf-8

from django.contrib import admin

from django_kippo.models import Auth, Client, Input, Sensor, Session, Ttylog
from django.conf import settings


class AuthAdmin(admin.ModelAdmin):
    list_display = ("id", "username", "password", "success", "timestamp")
    list_display_links = ("username", "password")
    list_filter = ("session",)
    date_hierarchy = 'timestamp'
    search_fields = ("username", "password")
admin.site.register(Auth, AuthAdmin)


class InputAdmin(admin.ModelAdmin):
    list_display = ("id", "realm", "input", "success", "timestamp")
    list_display_links = ("id",)
    list_filter = ("session",)
    date_hierarchy = 'timestamp'
    search_fields = ("input",)
admin.site.register(Input, InputAdmin)


class SessionAdmin(admin.ModelAdmin):
    list_display = ("id", "ip", "starttime", "endtime", "termsize", "client")
    list_display_links = ("ip",)
    list_filter = ("ip", "client")
    date_hierarchy = "starttime"
    search_fields = ("ip", "client")
admin.site.register(Session, SessionAdmin)


class TtylogAdmin(admin.ModelAdmin):
    pass
admin.site.register(Ttylog, TtylogAdmin)


if getattr(settings, "ADD_ALL_KIPPO_MODELS", False):
    class SensorAdmin(admin.ModelAdmin):
        list_display = ("id", "ip")
        list_display_links = ("ip",)
        search_fields = ("ip",)
    admin.site.register(Sensor, SensorAdmin)

    class ClientAdmin(admin.ModelAdmin):
        list_display = ("version",)
    admin.site.register(Client, ClientAdmin)



# coding: utf-8

from django.db import models


class Auth(models.Model):
    id = models.IntegerField(primary_key=True)
    session = models.ForeignKey("Session", db_column="session")
    success = models.IntegerField()
    username = models.CharField(max_length=300)
    password = models.CharField(max_length=300)
    timestamp = models.DateTimeField()

    def __unicode__(self):
        result = u"Kippo Auth [%s/%s]" % (self.username, self.password)
        if self.success == 1:
            result += " successfully."
        else:
            result += " failed."
        return result

    class Meta:
        db_table = u'auth'
        ordering = ('-timestamp',)

class Client(models.Model):
    id = models.IntegerField(primary_key=True)
    version = models.CharField(max_length=150, help_text="Used SSH Client (maybe faked).")

    def __unicode__(self):
        return "Client '%s'" % self.version

    class Meta:
        db_table = u'clients'


class Input(models.Model):
    id = models.IntegerField(primary_key=True)
    session = models.ForeignKey("Session", db_column="session")
    timestamp = models.DateTimeField()
    realm = models.CharField(max_length=150, blank=True)
    success = models.IntegerField(null=True, blank=True)
    input = models.TextField()
    class Meta:
        db_table = u'input'


class Sensor(models.Model):
    id = models.IntegerField(primary_key=True)
    ip = models.CharField(max_length=45, help_text="IP from kippo instance.")
    def __unicode__(self):
        return "IP: %s" % self.ip
    class Meta:
        db_table = u'sensors'


class Session(models.Model):
    id = models.CharField(max_length=96, primary_key=True)
    starttime = models.DateTimeField()
    endtime = models.DateTimeField(null=True, blank=True)
    sensor = models.ForeignKey("Sensor", db_column="sensor", help_text="Kippo instance")
    ip = models.CharField(max_length=45, help_text="IP from remote SSH client.")
    termsize = models.CharField(max_length=21, blank=True)
    client = models.ForeignKey("Client", db_column="client", null=True, blank=True)
    def __unicode__(self):
        return "Session %s" % self.id
    class Meta:
        db_table = u'sessions'


class Ttylog(models.Model):
    id = models.IntegerField(primary_key=True)
    session = models.ForeignKey("Session", db_column="session")
    ttylog = models.TextField()
    def __unicode__(self):
        return "tty log from session %s" % self.session.id
    class Meta:
        db_table = u'ttylog'




# coding: utf-8

"""
    Django settings for test_project project.
"""

import os
import sys

#for path in sys.path:print path

#import django_kippo
import django_kippo_test_project

def _pkg_path(obj, subdir=None):
    abspath = os.path.abspath(os.path.dirname(obj.__file__))
    if subdir is not None:
        abspath = os.path.join(abspath, subdir)
    return abspath

DEBUG = True
TEMPLATE_DEBUG = DEBUG

ADMINS = (
    # ('Your Name', 'your_email@example.com'),
)

MANAGERS = ADMINS

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
#        'NAME': _pkg_path(django_kippo_test_project, "test.db3"),
        'NAME': os.path.join(os.path.abspath(os.path.dirname(__file__)), "test.db3"),
    }
}

SITE_ID = 1

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

# If you set this to False, Django will not format dates, numbers and
# calendars according to the current locale
USE_L10N = True

# Absolute path to the directory static files should be collected to.
# Don't put anything in this directory yourself; store your static files
# in apps' "static/" subdirectories and in STATICFILES_DIRS.
# Example: "/home/media/media.lawrence.com/static/"
STATIC_ROOT = ''

# URL prefix for static files.
# Example: "http://media.lawrence.com/static/"
STATIC_URL = '/static/'

# URL prefix for admin static files -- CSS, JavaScript and images.
# Make sure to use a trailing slash.
# Examples: "http://foo.com/static/admin/", "/static/admin/".
ADMIN_MEDIA_PREFIX = '/static/admin/'

# Additional locations of static files
STATICFILES_DIRS = (
    # Put strings here, like "/home/html/static" or "C:/www/django/static".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
)

# List of finder classes that know how to find static files in
# various locations.
STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
#    'django.contrib.staticfiles.finders.DefaultStorageFinder',
)

# Make this unique, and don't share it with anybody.
SECRET_KEY = "change me, i'm not secret"

# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
#     'django.template.loaders.eggs.Loader',
)

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    "reversion.middleware.RevisionMiddleware",
    #"django_kippo_test_project.django_kippo_test_app.middleware.QueryLogMiddleware",
)

ROOT_URLCONF = 'django_kippo_test_project.urls'

TEMPLATE_DIRS = (
    # Put strings here, like "/home/html/django_templates" or "C:/www/django/templates".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
)

INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.admin',
    'django.contrib.admindocs',
    'django_kippo',
#    'south',
)

# A sample logging configuration. The only tangible logging
# performed by this configuration is to send an email to
# the site admins on every HTTP 500 error.
# See http://docs.djangoproject.com/en/dev/topics/logging for
# more details on how to customize your logging configuration.
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'class': 'django.utils.log.AdminEmailHandler'
        }
    },
    'loggers': {
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': True,
        },
    }
}

#------------------------------------------------------------------------------

# Add all kippo models to admin ?
ADD_ALL_KIPPO_MODELS = False

#------------------------------------------------------------------------------

try:
    from local_settings import *
except ImportError, err:
    if str(err).startswith("No module named"):
        msg = (
            "There is no local_settings.py file in '%s' !"
            " (Original error was: %s)\n"
        ) % (os.getcwd(), err)
        from django.core.exceptions import ImproperlyConfigured
        raise ImproperlyConfigured(msg)
    else:
        raise
